@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from sqlglot import exp, generator, parser, tokens
-from sqlglot.dialects.dialect import Dialect
+from sqlglot.dialects.dialect import Dialect, min_or_least
 from sqlglot.tokens import TokenType
 
 
@@ -126,6 +126,11 @@ class Teradata(Dialect):
             exp.PartitionedByProperty: exp.Properties.Location.POST_INDEX,
         }
 
+        TRANSFORMS = {
+            **generator.Generator.TRANSFORMS,
+            exp.Min: min_or_least,
+        }
+
         def partitionedbyproperty_sql(self, expression: exp.PartitionedByProperty) -> str:
             return f"PARTITION BY {self.sql(expression, 'this')}"
 
